@@ -3,6 +3,10 @@
 
 #include <libps/pslib.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 PSLIB_API void PSLIB_CALL
 PS_mp_init(void);
 
@@ -18,4 +22,8 @@ PS_mp_free(PSDoc *p, void *mem);
 PSLIB_API void PSLIB_CALL
 PS_mp_list_unfreed();
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
