@@ -3,6 +3,10 @@
 
 #include <stdio.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifdef WIN32
 
 #define PSLIB_CALL __cdecl
@@ -337,4 +341,8 @@ PS_symbol_name(PSDoc *psdoc, unsigned char c, int fontid, char *name, int size);
 PSLIB_API int PSLIB_CALL
 PS_include_file(PSDoc *psdoc, const char *filename);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
