@@ -749,18 +749,25 @@ handlereencoding(ADOBEFONTMETRIC *metric) {
 /* rmkernmatch() {{{
  *
  * Some routines to remove kerns that match certain patterns.
- * FIXME: kern pairs are removed without freeing the memory
  */
-static KERN *rmkernmatch(KERN *k, char *s)
+static KERN *rmkernmatch(PSDoc *psdoc, KERN *k, char *s)
 {
-	KERN *nk ;
+	KERN *nk, *ktmp ;
 
-	while (k != NULL && strcmp(k->succ, s)==0)
-		k = k->next ;
+	while (k != NULL && strcmp(k->succ, s)==0) {
+		psdoc->free(psdoc, k->succ);
+		ktmp = k->next;
+		psdoc->free(psdoc, k);
+		k = ktmp;
+	}
 	if (k) {
 		for (nk = k; nk; nk = nk->next)
-			while (nk->next && strcmp(nk->next->succ, s)==0)
-				nk->next = nk->next->next ;
+			while (nk->next && strcmp(nk->next->succ, s)==0) {
+				psdoc->free(psdoc, nk->next->succ);
+				ktmp = nk->next->next;
+				psdoc->free(psdoc, nk->next);
+				nk->next = ktmp;
+			}
 	}
 	return k ;
 }
@@ -769,7 +776,6 @@ static KERN *rmkernmatch(KERN *k, char *s)
 /* rmkern() {{{
  *
  * Recursive to one level.
- * FIXME: kern pairs are removed without freeing the memory
  */
 static void rmkern(PSDoc *psdoc, ght_hash_table_t *gadobechars, char *s1, char *s2, ADOBEINFO *ai)
 {
@@ -788,10 +794,19 @@ static void rmkern(PSDoc *psdoc, ght_hash_table_t *gadobechars, char *s1, char *
 				return ;
 		}
 	}
-	if (strcmp(s2, "*")==0)
-		ai->kerns = 0 ; /* drop them on the floor */
-	else
-		ai->kerns = rmkernmatch(ai->kerns, s2) ;
+	if (strcmp(s2, "*")==0) {
+		KERN *k, *ktmp;
+		k = ai->kerns;
+		while(k != NULL) {
+			if(k->succ)
+				psdoc->free(psdoc, k->succ);
+			ktmp = k->next;
+			psdoc->free(psdoc, k);
+			k = ktmp;
+		}
+		ai->kerns = NULL ; /* drop them on the floor */
+	} else
+		ai->kerns = rmkernmatch(psdoc, ai->kerns, s2) ;
 }
 /* }}} */
 
