@@ -18,6 +18,9 @@ void ps_error(PSDoc *p, int type, const char *fmt, ...) {
 	char msg[256];
 	va_list ap;
 
+	if(type == PS_Warning && p->warnings == ps_false)
+		return;
+
 	va_start(ap, fmt);
 	vsprintf(msg, fmt, ap);
 
