@@ -18,7 +18,7 @@ ENCODING fontencoding = {
 	 "h", "i", "j", "k", "l", "m", "n", "o",
 	 "p", "q", "r", "s", "t", "u", "v", "w",
 	 "x", "y", "z", "braceleft", "bar", "braceright", "asciitilde", "",
-	 "", "", "quotesinglbase", "florin", "quotedblbase", "ellipsis", "dagger", "daggerdbl",
+	 "Euro", "", "quotesinglbase", "florin", "quotedblbase", "ellipsis", "dagger", "daggerdbl",
 	 "circumflex", "perthousand", "Scaron", "guilsinglleft", "OE", "", "", "",
 	 "", "", "", "quotedblleft", "quotedblright", "bullet", "endash", "emdash",
 	 "tilde", "trademark", "scaron", "guilsinglright", "oe", "", "", "Ydieresis",
