@@ -22,7 +22,7 @@ ENCODING inputencoding = {
 	 "", "", "", "", "", "", "", "",
 	 "dotlessi", "grave", "acute", "circumflex", "tilde", "macron", "breve", "dotaccent",
 	 "dieresis", "", "ring", "cedilla", "", "hungarumlaut", "ogonek", "caron",
-	 "space", "exclamdown", "cent", "sterling", "currency", "yen", "brokenbar", "section",
+	 "space", "exclamdown", "cent", "sterling", "Euro", "yen", "brokenbar", "section",
 	 "dieresis", "copyright", "ordfeminine", "guillemotleft", "logicalnot", "hyphen", "registered", "macron",
 	 "degree", "plusminus", "twosuperior", "threesuperior", "acute", "mu", "paragraph", "periodcentered",
 	 "cedilla", "onesuperior", "ordmaskuline", "guillemotright", "onequarter", "onehalf", "threequaters", "questiondown",
