@@ -98,11 +98,16 @@ PS_mp_free(PSDoc *p, void *mem) {
 
 PSLIB_API void PSLIB_CALL
 PS_mp_list_unfreed() {
-	int i, j;
+	int i, j, l;
+	const char *ptr;
 	i = j = 0;
 	while(i < MAXMEM) {
 		if(memlist[i].ptr) {
 			fprintf(stderr, _("%d. Memory at address 0x%X (%d) not freed: '%s'."), j, (unsigned int) memlist[i].ptr, memlist[i].size, memlist[i].caller);
+			ptr = memlist[i].ptr;
+			for(l=0; l<memlist[i].size; l++, ptr++) {
+				fputc(*ptr, stderr);
+			}
 			fprintf(stderr, "\n");
 			j++;
 		}
