@@ -18,7 +18,7 @@
  *    Boston, MA 02111-1307, USA.
  */
 
-/* $Id: ps_util.c,v 1.33 2004/07/21 11:07:50 steinm Exp $ */
+/* $Id: ps_util.c,v 1.36 2005/06/20 11:34:04 steinm Exp $ */
 
 #include <stdio.h>
 #include <errno.h>
@@ -309,11 +309,12 @@ float ps_get_word_spacing(PSDoc *psdoc, PSFont *psfont) {
  * in ai. If that is the case the number of characters consumed in text
  * will be returned in offset and the name of the ligature will be returned
  * in newadobename.
- * Ligatures can be broken off by a ''. In such a case 1 will be returned
- * and offset is set to 1 in order to skip the ''. newadobename is set
+ * Ligatures can be broken off by a ligdischar. In such a case 1 will be
+ * returned
+ * and offset is set to 1 in order to skip the ligdischar. newadobename is set
  * to the name of the passed character.
  */
-int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char **newadobename, int *offset) {
+int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char ligdischar, char **newadobename, int *offset) {
 	ADOBEINFO *nextai;
 	LIG *ligs;
 	if((NULL == ai) || (NULL == ai->ligs))
@@ -322,10 +323,11 @@ int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text,
 		return 0;
 
 	ligs = ai->ligs;
-	/*  breaks ligatures. The idea is, that every char followed by a ''
+	/* ligdischar breaks ligatures. The idea is, that every char followed
+	 * by a ligdischar
 	 * forms a ligature which is the char itself. Setting offset to
-	 * 1 will skip the '' */
-	if(ligs && text[0] == '') {
+	 * 1 will skip the ligdischar */
+	if(ligs && text[0] == ligdischar) {
 		*offset += 1;
 		*newadobename = ai->adobename;
 		return 1;
@@ -342,7 +344,7 @@ int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text,
 		 * ligature. First check if current char and ligature of 2nd and 3th
 		 * char for a ligature.
 		 */
-		if(ps_check_for_lig(metrics, nextai, &text[1], &nextadobename, &_offset)) {
+		if(ps_check_for_lig(metrics, nextai, &text[1], ligdischar, &nextadobename, &_offset)) {
 			while(ligs) {
 				if(0 == strcmp(ligs->succ, nextadobename)) {
 					*offset += 1+_offset;
@@ -367,7 +369,7 @@ int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text,
 				 */
 				ligai = gfindadobe(metrics->gadobechars, ligs->sub);
 				if(ligai) {
-					if(ps_check_for_lig(metrics, ligai, &text[1], &nextadobename, offset)) {
+					if(ps_check_for_lig(metrics, ligai, &text[1], ligdischar, &nextadobename, offset)) {
 						*newadobename = nextadobename;
 						return 1;
 
@@ -589,10 +591,16 @@ int ps_ascii85_encode(PSDoc *psdoc, char *data, size_t len) {
 	unsigned char c;
 	int i, count, cc;
 
+	buffer = 0;
 	count = 0;
 	cc = 0;
 	while(count <= len-4) {
-		buffer = ((long) data[count] << 24) + ((long) data[count+1] << 16) + ((long) data[count+2] << 8) + (long) data[count+3];
+//		buffer = ((long) data[count] << 24) + ((long) data[count+1] << 16) + ((long) data[count+2] << 8) + (long) data[count+3];
+		buffer |= ((unsigned char) data[count] << 24);
+		buffer |= ((unsigned char) data[count+1] << 16);
+		buffer |= ((unsigned char) data[count+2] << 8);
+		buffer |= ((unsigned char) data[count+3]);
+
 		if(buffer == 0) {
 			ps_putc(psdoc, 'z');
 			cc++;
@@ -637,7 +645,7 @@ int ps_asciihex_encode(PSDoc *psdoc, char *data, size_t len) {
 		ps_printf(psdoc, "%02x", *dataptr);
 		dataptr ++;
 		cc++;
-		if(cc > 35) {
+		if(cc > 35 && i < (len-1)) {
 			ps_printf(psdoc, "\n");
 			cc = 0;
 		}
@@ -720,8 +728,6 @@ ght_hash_table_t *ps_parse_optlist(PSDoc *psdoc, const char *optstr) {
  * Returns -1 if the parameter is not available and -2 if it is available
  * but the value cannot be retrieved.
  */
-/* FIXME: For some reason this prototype is needed for strtof() to work */
-float strtof(const char *nptr, char **endptr);
 int get_optlist_element_as_float(PSDoc *psdoc, ght_hash_table_t *opthash, const char *name, float *value) {
 	float tmp;
 	char *strval;
@@ -733,7 +739,7 @@ int get_optlist_element_as_float(PSDoc *psdoc, ght_hash_table_t *opthash, const
 	if(NULL == (strval = ght_get(opthash, strlen(name)+1, (void *) name))) {
 		return(-1);
 	}
-	tmp = strtof(strval, &endval);
+	tmp = (float) strtod(strval, &endval);
 	if(endval == strval) {
 		return(-2);
 	}
